# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2017 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2017, Creative Commons
Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""

from . import layout_10


class bloco_0(layout_10.bloco_0):
    """Classe do Bloco 0"""

    class registro_0001(layout_10.bloco_0.registro_0001):
        """
        REGISTRO 0001: ABERTURA DO BLOCO 0
        Este registro deve ser gerado para abertura do Bloco 0 e indica se há informações previstas
        para este bloco.
        """

        def __init__(self):
            super(bloco_0.registro_0001, self).__init__()

    class registro_0005(layout_10.bloco_0.registro_0005):
        """
        REGISTRO 0005: DADOS COMPLEMENTARES DA ENTIDADE
        Registro obrigatório utilizado para complementar as informações de identificação do informante
        do arquivo.
        """

        def __init__(self):
            super(bloco_0.registro_0005, self).__init__()

    class registro_0015(layout_10.bloco_0.registro_0015):
        """
        REGISTRO 0015: DADOS DO CONTRIBUINTE SUBSTITUTO
        Registro obrigatório para todos os contribuintes substitutos tributários do ICMS, conforme
        definidos na legislação pertinente. Deve ser gerado um registro para cada uma das inscrições
        estaduais cadastradas nas unidades federadas dos contribuintes substituídos, ainda que não
        tenha tido movimentação no período, ficando obrigado à apresentação dos registros E200 e filhos.
        """

        def __init__(self):
            super(bloco_0.registro_0015, self).__init__()

    class registro_0100(layout_10.bloco_0.registro_0100):
        """
        REGISTRO 0100: DADOS DO CONTABILISTA
        Registro utilizado para identificação do contabilista responsável pela escrituração fiscal do
        estabelecimento, mesmo que o contabilista seja funcionário da empresa ou prestador de serviço.
        """
        def __init__(self):
            super(bloco_0.registro_0100, self).__init__()

    class registro_0150(layout_10.bloco_0.registro_0150):
        """
        REGISTRO 0150: TABELA DE CADASTRO DO PARTICIPANTE
        Registro utilizado para informações cadastrais das pessoas físicas ou jurídicas envolvidas nas
        transações comerciais com o estabelecimento, no período. Participantes sem movimentação no
        período não devem ser informados
        neste registro.
        """
        def __init__(self):
            super(bloco_0.registro_0150, self).__init__()

    class registro_0175(layout_10.bloco_0.registro_0175):
        """
        REGISTRO 0175: Alteração da Tabela de Cadastro de Participante
        Este registro é de preenchimento obrigatório quando houver, dentro do período, alteração nos
        dados informados no registro 0150, campos: NOME, COD_PAIS, CNPJ, CPF, IE, COD_MUN, SUFRAMA,
        END, NUM, COMPL e BAIRRO. Não pode ser utilizado, em um mesmo arquivo, um mesmo código para
        representar um participante diferente do referenciado anteriormente por tal código. Os dados
        informados neste registro serão considerados até às 24:00 horas do dia anterior à data de
        alteração.
        """
        def __init__(self):
            super(bloco_0.registro_0175, self).__init__()

    class registro_0190(layout_10.bloco_0.registro_0190):
        """
        REGISTRO 0190: IDENTIFICAÇÃO DAS UNIDADES DE MEDIDA
        Este registro tem por objetivo descrever as unidades de medidas utilizadas no arquivo digital.
        Não podem ser informados dois ou mais registros com o mesmo código de unidade de medida.
        Somente devem constar as unidades de medidas informadas nos demais blocos.
        """
        def __init__(self):
            super(bloco_0.registro_0190, self).__init__()

    class registro_0200(layout_10.bloco_0.registro_0200):
        """
        REGISTRO 0200: TABELA DE IDENTIFICAÇÃO DO ITEM (PRODUTO E SERVIÇOS)
        Este registro tem por objetivo informar mercadorias, serviços, produtos ou quaisquer outros
        itens concernentes às transações fiscais. Quando ocorrer alteração somente na descrição do
        item, sem que haja descaracterização deste, ou seja, criação de um novo item, a alteração deve
        constar no registro 0205. Só devem ser apresentados itens referenciados nos demais blocos.
        """
        def __init__(self):
            super(bloco_0.registro_0200, self).__init__()
            self.layout = 11
            self.CEST = ''  # Codigo especificador da Substituicao Tributaria
            self.fieldnames = ('REG', 'COD_ITEM', 'DESCR_ITEM', 'COD_BARRA', 'COD_ANT_ITEM',
                               'UNID_INV', 'TIPO_ITEM', 'COD_NCM', 'EX_IPI', 'COD_GEN', 'COD_LST',
                               'ALIQ_ICMS', 'CEST')
            self.formato = self.get_formato()

    class registro_0205(layout_10.bloco_0.registro_0205):
        """
        REGISTRO 0205: ALTERAÇÃO DO ITEM
        Este registro tem por objetivo informar alterações ocorridas na descrição do produto, desde que
        não o descaracterize ou haja modificação que o identifique como sendo novo produto, caso não
        tenha ocorrido movimentação no período da alteração do item, deverá ser informada no primeiro
        período em que houver movimentação do item. Deverá ser ainda informado quando ocorrer alteração
        na codificação do produto. Não podem ser informados dois ou mais registros com sobreposição de
        períodos.
        """
        def __init__(self):
            super(bloco_0.registro_0205, self).__init__()

    class registro_0206(layout_10.bloco_0.registro_0206):
        """
        REGISTRO 0206: CÓDIGO DE PRODUTO CONFORME TABELA PUBLICADA PELA ANP (COMBUSTÍVEIS)
        Este registro tem por objetivo informar o código correspondente ao produto constante na Tabela
        da Agência Nacional de Petróleo (ANP) para os produtos denominados “Combustíveis”. Deve ser
        apresentado apenas pelos contribuintes produtores, importadores e distribuidores de
        combustíveis.
        """
        def __init__(self):
            super(bloco_0.registro_0206, self).__init__()

    class registro_0220(layout_10.bloco_0.registro_0220):
        """
        REGISTRO 0220: FATORES DE CONVERSÃO DE UNIDADES
        Este registro tem por objetivo informar os fatores de conversão dos itens discriminados na
        Tabela de Identificação do Item (Produtos e Serviços) entre a unidade informada no registro
        0200 e as unidades informadas nos registros dos
        documentos fiscais.
        """
        def __init__(self):
            super(bloco_0.registro_0220, self).__init__()

    class registro_0300(layout_10.bloco_0.registro_0300):
        """
        REGISTRO 0300: CADASTRO DE BENS OU COMPONENTES DO ATIVO IMOBILIZADO
        Este registro tem o objetivo de identificar e caracterizar todos os bens ou componentes
        arrolados no registro G125 do Bloco G e os bens em construção.
        """
        def __init__(self):
            super(bloco_0.registro_0300, self).__init__()

    class registro_0305(layout_10.bloco_0.registro_0305):
        """
        REGISTRO 0305 – INFORMAÇÃO SOBRE A UTILIZAÇÃO DO BEM
        Este registro tem o objetivo de prestar informações sobre a utilização do bem, sendo
        obrigatório quando o conteúdo do campo IDENT_MERC do registro 0300 for igual a “1”.
        """
        def __init__(self):
            super(bloco_0.registro_0305, self).__init__()

    class registro_0400(layout_10.bloco_0.registro_0400):
        """
        REGISTRO 0400: TABELA DE NATUREZA DA OPERAÇÃO/PRESTAÇÃO
        Este registro tem por objetivo codificar os textos das diferentes naturezas da
        operação/prestação discriminadas nos documentos fiscais. Esta codificação e suas descrições são
        livremente criadas e mantidas pelo contribuinte. Este registro não se refere a CFOP. Algumas
        empresas utilizam outra classificação além das apresentados nos CFOP. Esta codificação permite
        informar estes agrupamentos próprios. Não podem ser informados dois ou mais registros com o
        mesmo conteúdo no campo COD_NAT
        """
        def __init__(self):
            super(bloco_0.registro_0400, self).__init__()

    class registro_0450(layout_10.bloco_0.registro_0450):
        """
        REGISTRO 0450: TABELA DOCUMENTO FISCAL DE INFORMAÇÃO COMPLEMENTAR DO DOCUMENTO FISCAL
        Este registro tem por objetivo codificar todas as informações complementares dos documentos
        fiscais, exigidas pela legislação fiscal. Estas informações constam no campo “Dados Adicionais”
        dos documentos fiscais.
        """
        def __init__(self):
            super(bloco_0.registro_0450, self).__init__()

    class registro_0460(layout_10.bloco_0.registro_0460):
        """
        REGISTRO 0460: TABELA DE OBSERVAÇÕES DO LANÇAMENTO FISCAL
        Este registro é utilizado para informar anotações de escrituração determinadas pela legislação
        pertinente aos lançamentos fiscais, tais como: ajustes efetuados por diferimento parcial de
        imposto, antecipações, diferencial de alíquota e outros.Esta codificação e suas descrições são
        de atribuição do contribuinte e não podem ser informados dois ou mais registros com o mesmo
        conteúdo no campo COD_OBS.
        """
        def __init__(self):
            super(bloco_0.registro_0460, self).__init__()

    class registro_0500(layout_10.bloco_0.registro_0500):
        """
        REGISTRO 0500: PLANO DE CONTAS CONTÁBEIS
        Este registro tem o objetivo de identificar as contas contábeis utilizadas pelo contribuinte
        informante em sua Contabilidade Geral, no que se refere às contas referenciadas no registro
        0300. Não podem ser informados dois ou mais registros com a mesma combinação de conteúdo nos
        campos DT_ALT e COD_CTA.
        """
        def __init__(self):
            super(bloco_0.registro_0500, self).__init__()

    class registro_0600(layout_10.bloco_0.registro_0600):
        """
        REGISTRO 0600: CENTRO DE CUSTOS
        Este registro tem o objetivo de identificar os centros de custos referenciados no registro 0305.
        Não podem ser informados dois ou mais registros com a mesma combinação de conteúdo nos campos
        DT_ALT e COD_CCUS.
        """
        def __init__(self):
            super(bloco_0.registro_0600, self).__init__()

    class registro_0990(layout_10.bloco_0.registro_0990):
        """
        REGISTRO 0990: ENCERRAMENTO DO BLOCO 0
        Este registro tem por objetivo identificar o encerramento do bloco 0 e informar a quantidade de
        linhas (registros)
        existentes no bloco.
        """
        def __init__(self):
            super(bloco_0.registro_0990, self).__init__()


class bloco_1(layout_10.bloco_1):
    pass


class bloco_c(layout_10.bloco_c):
    pass


class bloco_e(layout_10.bloco_e):
    """ Classe do bloco e"""

    class registro_E310(layout_10.bloco_e.registro_E310):
        """
        REGISTRO E310 – APURAÇÃO  DO ICMS DIFERENCIAL DE ALIQUOTA
        Este registro tem por objetivo informar valores relativos à apuração do ICMS – Diferencial
        de Alíquota e Fundo de Combate à Pobreza - FCP, por UF origem/destino, mesmo nos casos de
        períodos sem movimento. Registro obrigatório, se existir o registro E300.
        """

        def __init__(self):
            super(bloco_e.registro_E310, self).__init__()
            self.layout = 11
            self.IND_MOV_FCP_DIFAL = ''
            self.VL_SLD_CRED_ANT_FCP = ''
            self.VL_OUT_DEB_FCP = ''
            self.VL_OUT_CRED_FCP = ''
            self.VL_SLD_DEV_ANT_FCP = ''
            self.VL_DEDUCOES_FCP = ''
            self.VL_RECOL_FCP = ''
            self.VL_SLD_CRED_TRANSPORTAR_FCP = ''
            self.DEB_ESP_FCP = ''
            self.fieldnames = ('REG', 'IND_MOV_FCP_DIFAL', 'VL_SLD_CRED_ANT_DIFAL',
                               'VL_TOT_DEBITOS_DIFAL', 'VL_OUT_DEB_DIFAL', 'VL_TOT_CREDITOS_DIFAL',
                               'VL_OUT_CRED_DIFAL', 'VL_SLD_DEV_ANT_DIFAL', 'VL_DEDUCOES_DIFAL',
                               'VL_RECOL', 'VL_SLD_CRED_TRANSPORTAR', 'DEB_ESP_DIFAL',
                               'VL_SLD_CRED_ANT_FCP', 'VL_TOT_DEB_FCP', 'VL_OUT_DEB_FCP',
                               'VL_TOT_CRED_FCP', 'VL_OUT_CRED_FCP', 'VL_SLD_DEV_ANT_FCP',
                               'VL_DEDUCOES_FCP', 'VL_RECOL_FCP', 'VL_SLD_CRED_TRANSPORTAR_FCP',
                               'DEB_ESP_FCP')
            self.formato = self.get_formato()


# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

