# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2019 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2019, Creative Commons
Autor - Tiago Henrique Prates dos Santos <tiago.santos[at]siginformatica.com.br>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from . import layout_13
from .layout_13 import bloco_c  as efd_bloco_c
from .bloco_g import bloco_g as efd_bloco_g
from .layout_13 import bloco_1 as efd_bloco_1
from ..utils import TrackedAttributesClass

# Ato COTEPE/ICMS item 3.1.1 - Tabela Versao do Leiaute
_obrigatoriedade_ = '01/01/2020'
_codigo_ = '014'  # layout_14
_versao_ = '113'


class bloco_0(layout_13.bloco_0):

    class registro_0002(TrackedAttributesClass):
        """
        REGISTRO 0002: CLASSIFICAÇÃO DO ESTABELECIMENTO INDUSTRIAL OU EQUIPARADO A INDUSTRIAL
        O registro deve ser informado quando o campo IND_ATIV do registro 0000 for igual a “0”.
        Quando existir mais de um tipo de modalidade, informar a classificação que for mais
        relevante no estabelecimento.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0002, self).__init__()
            self.REG = '0002'
            self.nivel_h = 1  # nivel
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrencia por arquivo
            self.CLAS_ESTAB_IND = ''
            self.fieldnames = ('REG', 'CLAS_ESTAB_IND')
            self.formato = self.get_formato()


class bloco_e(layout_13.bloco_e):
    pass


class bloco_1(efd_bloco_1):
    """
    BLOCO 1: OUTRAS INFORMAÇÕES
    Este bloco destina-se à prestação de outras informações exigidas pelo fisco.
    """

    class registro_1010(efd_bloco_1.registro_1010):
        """
        REGISTRO 1010: OBRIGATORIEDADE DE REGISTROS DO BLOCO 1
        Este registro deverá ser apresentado por todos os contribuintes. Caso a resposta seja “S”,
        o contribuinte está obrigado à apresentação do registro respectivo. Se houver dispensa de
        apresentação do registro pela unidade federada, a resposta para o campo específico do
        registro deverá ser “N”.
        """
        def __init__(self):
            super(bloco_1.registro_1010, self).__init__()
            self.IND_REST_RESSARC_COMPL_ICMS = ''
            self.fieldnames = ('REG', 'IND_EXP', 'IND_CCRF', 'IND_COMB', 'IND_USINA', 'IND_VA',
                               'IND_EE', 'IND_CART', 'ND_FORM', 'IND_AER', 'IND_GIAF1', 'IND_GIAF3',
                               'IND_GIAF4', 'IND_REST_RESSARC_COMPL_ICMS')
            self.formato = self.get_formato()


class bloco_c(efd_bloco_c):
    """
    BLOCO C: DOCUMENTOS FISCAIS I - MERCADORIAS (ICMS/IPI)
    """

    class registro_C500(efd_bloco_c.registro_C500):
        def __init__(self):
            super(bloco_c.registro_C500, self).__init__()
            self.CHV_DOCe = ''  # Chave da Nota Fiscal de Energia Elétrica Eletrônica
            self.FIN_DOCe = ''  # Finalidade da emissão do documento eletrônico: 1 – Normal, 2 – Substituição, 3 – Normal com ajuste
            self.CHV_DOCe_REF = ''  # Chave da nota referenciada
            self.IND_DEST = ''  # Indicador do Destinatário/Acessante:1 – Contribuinte do ICMS;2 – Contribuinte Isento de Inscrição no Cadastro de Contribuintes do ICMS;9 – Não Contribuinte.
            self.COD_MUN_DEST = ''  # Código do município do destinatário conforme a tabela do IBGE.
            self.COD_CTA = ''  # Código da conta analítica contábil debitada/creditada
            self.fieldnames = ('REG', 'IND_OPER', 'IND_EMIT', 'COD_PART', 'COD_MOD', 'COD_SIT',
                               'SER', 'SUB', 'COD_CONS', 'NUM_DOC', 'DT_DOC', 'DT_E_S', 'VL_DOC',
                               'VL_DESC', 'VL_FORN', 'VL_SERV_NT', 'VL_TERC', 'VL_DA', 'VL_BC_ICMS',
                               'VL_ICMS', 'VL_BC_ICMS_ST', 'VL_ICMS_ST', 'COD_INF', 'VL_PIS',
                               'VL_COFINS', 'TP_LIGACAO', 'COD_GRUPO_TENSAO', 'CHV_DOCe',
                               'FIN_DOCe', 'CHV_DOCe_REF', 'IND_DEST', 'COD_MUN_DEST', 'COD_CTA')
            self.formato = self.get_formato()

class bloco_g(efd_bloco_g):
    """
    BLOCO C: DOCUMENTOS FISCAIS I - MERCADORIAS (ICMS/IPI)
    """

    class registro_G130(efd_bloco_g.registro_G130):
        def __init__(self):
            super(bloco_g.registro_G130, self).__init__()
            self.NUM_DA = ''  # Número do documento de arrecadação estadual, se houver
            self.fieldnames = ('REG', 'IND_EMIT', 'COD_PART', 'COD_MOD', 'SERIE', 'NUM_DOC',
                               'CHV_NFE_CTE', 'DT_DOC', 'NUM_DA')
            self.formato = self.get_formato()

    class registro_G140(efd_bloco_g.registro_G140):
        def __init__(self):
            super(bloco_g.registro_G140, self).__init__()
            self.QTDE = ''  # Quantidade, deste item da nota fiscal, que foi aplicadaneste bem, expressa na mesma unidade constante nodocumento fiscal de entrada
            self.UNID = ''  # Unidade do item constante no documento fiscal deentrada
            self.VL_ICMS_OP_APLICADO = ''  # Valor do ICMS  da Operação Própria na entrada doitem, proporcional à quantidade aplicada no bem oucomponente
            self.VL_ICMS_ST_APLICADO = ''  # Valor do ICMS ST na entrada do item, proporcional àquantidade aplicada no bem ou componente.
            self.VL_ICMS_FRT_APLICADO = ''  # Valor do ICMS sobre Frete do Conhecimento deTransporte na entrada do item, proporcional àquantidade aplicada no bem ou componente.
            self.VL_ICMS_DIF_APLICADO = ''  # Valor do ICMS Diferencial de Alíquota, na entrada doitem, proporcional à quantidade aplicada no bem oucomponente.

            self.fieldnames = ('REG', 'NUM_ITEM', 'COD_ITEM', 'QTDE', 'UNID', 'VL_ICMS_OP_APLICADO',
                               'VL_ICMS_ST_APLICADO', 'VL_ICMS_FRT_APLICADO', 'VL_ICMS_DIF_APLICADO')
            self.formato = self.get_formato()
